<!--
SPDX-FileCopyrightText: 2022 Contributors to the Power Grid Model project <dynamic.grid.calculation@alliander.com>

SPDX-License-Identifier: MPL-2.0
-->
## Component Test Case: Node (Basic)

Test case for validation of basic functioning the node component for symmetrical power flow calculations in pandapower. 
- A node can have 2 states: energized and non-energized.

The circuit diagram is as follows:
```
source_4--node_1       node_2
```
